@@ -4,6 +4,7 @@ library(knitr)
 knitr::opts_chunk$set(
    cache = TRUE,
    dpi = 75,
+   fig.width = 6, fig.height = 6,
   # comment = "#>",
   tidy = FALSE)
 
@@ -12,7 +13,7 @@ knitr::opts_chunk$set(
 
 
 ## ------------------------------------------------------------------------
-library(dendextend)
+library(dendextend) #
 
 ## ------------------------------------------------------------------------
 dend <- c(1:5) %>% dist %>% hclust("ave") %>% as.dendrogram
