@@ -830,8 +830,6 @@ FM_index(cutree(hc1, k=3), cutree(hc2, k=3))
          
 # Using the R code:
 FM_index_R(cutree(hc1, k=3), cutree(hc2, k=3))
-# Or wrapping the code from profdpm: (notice the NA's)
-FM_index_profdpm(cutree(hc1, k=3), cutree(hc2, k=3))
 
 ## ------------------------------------------------------------------------
 FM_index(cutree(hc1, k=3), cutree(hc2, k=3)) 
